@@ -99,7 +99,9 @@ in buckets. Bucket names are global.
 Note: This is the legacy interface, please check out
 L<Net::Amazon::S3::Client> instead.
 
-Development of this code happens here: http://github.com/acme/net-amazon-s3
+Development of this code happens here: http://github.com/pfig/net-amazon-s3/
+
+Homepage for the project (just started) is at http://pfig.github.com/net-amazon-s3/
 
 =cut
 
@@ -142,7 +144,7 @@ has 'errstr' => ( is => 'rw', isa => 'Maybe[Str]',     required => 0 );
 
 __PACKAGE__->meta->make_immutable;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 my $KEEP_ALIVE_CACHESIZE = 10;
 
@@ -787,7 +789,7 @@ sub _remember_errors {
 
 sub _urlencode {
     my ( $self, $unencoded ) = @_;
-    return uri_escape_utf8( $unencoded, '^A-Za-z0-9_-' );
+    return uri_escape_utf8( $unencoded, '^A-Za-z0-9_\-\.' );
 }
 
 1;
@@ -838,6 +840,8 @@ Leon Brocard <acme@astray.com> and unknown Amazon Digital Services programmers.
 
 Brad Fitzpatrick <brad@danga.com> - return values, Bucket object
 
+Pedro Figueiredo <me@pedrofigueiredo.org> - since 0.54
+
 =head1 SEE ALSO
 
 L<Net::Amazon::S3::Bucket>
